@@ -282,7 +282,7 @@ class GnuPG(object):
     """
 
     def __init__(self):
-        self.call = "gpg"
+        self.call = "/usr/pkg/bin/gpg2"
         self.passphrase = None
         self.options = Options()
 
